Learn R Programming

Sobol4R (version 0.4.0)

sobol_example_covariate_large: Example 3: Large covariate dependent random effect

Description

Third input C3 is uniform on [1, 100], used as the mean of a Gaussian noise term added to the G-function. Quantity of interest is the mean of repeated evaluations.

Usage

sobol_example_covariate_large(
  n = 50000,
  nrep_qoi = 1000,
  order = 2,
  nboot = 100
)

Value

A list with two "sobol" objects: x_single (single noisy run), x_qoi (QoI-based indices).

Arguments

n

Monte Carlo sample size for each base design.

nrep_qoi

Number of repetitions for the QoI.

order

Maximum interaction order.

nboot

Number of bootstrap replicates.