Learn R Programming

Sobol4R (version 0.4.0)

Sobol4R-package: Sobol4R-package

Description

Tools to design experiments, compute Sobol sensitivity indices, and summarise stochastic responses inspired by the strategy described by Zhu and Sudret (2021) tools:::Rd_expr_doi("10.1016/j.ress.2021.107815"). Includes helpers to optimise toy models implemented in C++, visualise indices with uncertainty quantification, and derive reliability-oriented sensitivity measures based on failure probabilities. It is further detailed in Logosha, Maumy and Bertrand (2022) tools:::Rd_expr_doi("10.1063/5.0246026") and (2023) tools:::Rd_expr_doi("10.1063/5.0246024") or in Bertrand, Logosha and Maumy (2024) https://hal.science/hal-05371803, https://hal.science/hal-05371795 and https://hal.science/hal-05371798.

Arguments

Author

Maintainer: Frederic Bertrand frederic.bertrand@lecnam.net (ORCID)

Authors:

References

Elizaveta Logosha, Myriam Maumy, Frederic Bertrand; Confidence interval determination using discrete event simulations for real estate sales case. AIP Conf. Proc. 31 March 2025; 3182 (1): 100008. tools:::Rd_expr_doi("10.1063/5.0246026").

Elizaveta Logosha, Myriam Maumy, Frédéric Bertrand; Sensitivity analysis of stochastic simulator in the case of sales date prediction. AIP Conf. Proc. 31 March 2025; 3182 (1): 100001. tools:::Rd_expr_doi("10.1063/5.0246024").

Frédéric Bertrand, Elizaveta Logosha, Myriam Maumy-Bertrand. Extension of sensitivity analysis to uncertainties in distribution parameters. 32nd Conference on Intelligent Systems for Molecular Biology, International Society for Computational Biology, Jul 2024, Montreal (QC), Canada. https://hal.science/hal-05371795.

Frédéric Bertrand, Elizaveta Logosha, Myriam Maumy-Bertrand. Sobol4RV: Global Sensitivity Analysis in Several Random Settings. BioC 2024, BioConductor, Jul 2024, Grand Rapids, MI, United States. https://hal.science/hal-05371803

Frédéric Bertrand, Elizaveta Logosha, Myriam Maumy-Bertrand. Global Sensitivity Analysis in Several Random Settings. 2024 Joint Statistical Meetings, American Statistical Association, Aug 2024, Portland (OR), United States. https://hal.science/hal-05371798.

See Also

sobol4r_design(), sobol4r_qoi_indices(), vignette("Sobol_RV_five_examples", package = "Sobol4R"), vignette("Sobol4R_vignette_stochastic", package = "Sobol4R"), vignette("Sobol4R_vignette_process", package = "Sobol4R") and vignette("simmer_MM1_Sobol_example", package = "Sobol4R").

Examples

Run this code
ex1_results <- sobol_example_g_deterministic(n=100, nboot=10) 
print(ex1_results)
autoplot(ex1_results, ncol = 1)
rm(ex1_results)

Run the code above in your browser using DataLab