Learn R Programming

Sobol4R (version 0.4.0)

estimate_failure_probability: Estimate Failure Probability from Simulator Outputs

Description

Convenient helper to compute the reliability-related probabilities described in Lebrun et al. (2021). The failure domain is controlled by a threshold and an inequality direction.

Usage

estimate_failure_probability(response, threshold, less = TRUE, weights = NULL)

Value

A list containing the estimated probability and its variance.

Arguments

response

Numeric vector of simulator evaluations.

threshold

Numeric scalar defining the failure boundary.

less

Logical, failure is defined as response <= threshold when TRUE and response >= threshold otherwise.

weights

Optional numeric vector of non-negative weights. The vector is normalised internally when supplied.

Examples

Run this code
y <- rnorm(1000)
estimate_failure_probability(y, threshold = -1)

Run the code above in your browser using DataLab