Learn R Programming

Sobol4R (version 0.4.0)

ishigami_model: Fast Ishigami Test Function

Description

C++ implementation of the Ishigami function that is widely used as a benchmark for Sobol sensitivity indices. The implementation is vectorised and therefore convenient for Monte Carlo experiments.

Usage

ishigami_model(x, a = 7, b = 0.1)

Value

Numeric vector of simulator outputs.

Arguments

x

Numeric matrix with three columns representing the inputs.

a

Numeric scalar controlling the nonlinear term.

b

Numeric scalar controlling the interaction term.

Examples

Run this code
x <- matrix(runif(30, -pi, pi), ncol = 3)
ishigami_model(x)

Run the code above in your browser using DataLab