Third input C3 is uniform on [1, 100], used as the mean of a Gaussian noise term added to the G-function. Quantity of interest is the mean of repeated evaluations.
sobol_example_covariate_large(
n = 50000,
nrep_qoi = 1000,
order = 2,
nboot = 100
)A list with two "sobol" objects:
x_single (single noisy run),
x_qoi (QoI-based indices).
Monte Carlo sample size for each base design.
Number of repetitions for the QoI.
Maximum interaction order.
Number of bootstrap replicates.