Learn R Programming

Sobol4R (version 0.4.0)

summarise_sobol: Summarise Sobol Indices

Description

Compute compact summaries of the Sobol indices and their Monte Carlo variability. The function is intended to feed diagnostic plots.

Usage

summarise_sobol(result, probs = c(0.1, 0.5, 0.9), bootstrap = 200L)

Value

A data frame (class sobol_summary) with the requested statistics. Quantile columns are added when probs is not empty.

Arguments

result

A sobol_result object.

probs

Numeric vector of probabilities used to report quantiles of the empirical bootstrap distribution.

bootstrap

Integer, number of bootstrap resamples used to quantify the estimator uncertainty.

Examples

Run this code
design <- sobol_design(n = 64, d = 3)
model <- function(x) ishigami_model(x)
sob <- sobol_indices(model, design, keep_samples = TRUE)
summarise_sobol(sob, probs = c(0.1, 0.9))

Run the code above in your browser using DataLab