powered by
Compute compact summaries of the Sobol indices and their Monte Carlo variability. The function is intended to feed diagnostic plots.
summarise_sobol(result, probs = c(0.1, 0.5, 0.9), bootstrap = 200L)
A data frame (class sobol_summary) with the requested statistics. Quantile columns are added when probs is not empty.
sobol_summary
probs
A sobol_result object.
sobol_result
Numeric vector of probabilities used to report quantiles of the empirical bootstrap distribution.
Integer, number of bootstrap resamples used to quantify the estimator uncertainty.
design <- sobol_design(n = 64, d = 3) model <- function(x) ishigami_model(x) sob <- sobol_indices(model, design, keep_samples = TRUE) summarise_sobol(sob, probs = c(0.1, 0.9))
Run the code above in your browser using DataLab